This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
       via  908cfab96a7cb0edbde586e6b31d28f36623577f (commit)
       via  ca0497c945460a10d2bb273be1f39e35c9c88742 (commit)
      from  c01d364e2bd3ce04cc251e44aa21022204d69176 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=908cfab96a7cb0edbde586e6b31d28f36623577f
commit 908cfab96a7cb0edbde586e6b31d28f36623577f
Merge: c01d364 ca0497c
Author:     Bill Hoffman <bill.hoff...@kitware.com>
AuthorDate: Wed Aug 31 11:24:16 2016 -0400
Commit:     CMake Topic Stage <kwro...@kitware.com>
CommitDate: Wed Aug 31 11:24:16 2016 -0400

    Merge topic 'extend_matlab_unit_test' into next
    
    ca0497c9 Extend matlab_add_unit_test to run arbitrary code for the test.


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=ca0497c945460a10d2bb273be1f39e35c9c88742
commit ca0497c945460a10d2bb273be1f39e35c9c88742
Author:     Bill Hoffman <bill.hoff...@kitware.com>
AuthorDate: Tue Aug 30 15:02:35 2016 -0400
Commit:     Bill Hoffman <bill.hoff...@kitware.com>
CommitDate: Wed Aug 31 10:42:13 2016 -0400

    Extend matlab_add_unit_test to run arbitrary code for the test.
    
    This commit allows a custom matlab set of commands to be run
    as the test instead of runtests('matlab_file_name'). It also
    escapes strings for matlab commands to allow for complicated
    matlab commands to be passed into the tests.

diff --git a/Modules/MatlabTestsRedirect.cmake 
b/Modules/MatlabTestsRedirect.cmake
index 0ef4c3e..5677ef6 100644
--- a/Modules/MatlabTestsRedirect.cmake
+++ b/Modules/MatlabTestsRedirect.cmake
@@ -23,11 +23,12 @@
 #   -DMatlab_PROGRAM=matlab_exe_location
 #   -DMatlab_ADDITIONNAL_STARTUP_OPTIONS=""
 #   -Dtest_name=name_of_the_test
+#   -Dcustom_Matlab_test_command=""
 #   -Dcmd_to_run_before_test=""
 #   -Dunittest_file_to_run
 #   -P FindMatlab_TestsRedirect.cmake
 
-set(Matlab_UNIT_TESTS_CMD -nosplash -nojvm -nodesktop -nodisplay 
${Matlab_ADDITIONNAL_STARTUP_OPTIONS})
+set(Matlab_UNIT_TESTS_CMD -nosplash -nodesktop -nodisplay 
${Matlab_ADDITIONNAL_STARTUP_OPTIONS})
 if(WIN32)
   set(Matlab_UNIT_TESTS_CMD ${Matlab_UNIT_TESTS_CMD} -wait)
 endif()
@@ -36,6 +37,13 @@ if(NOT test_timeout)
   set(test_timeout 180)
 endif()
 
+# If timeout is -1, then do not put a timeout on the execute_process
+if(test_timeout EQUAL -1)
+  set(test_timeout "")
+else()
+  set(test_timeout TIMEOUT ${test_timeout})
+endif()
+
 if(NOT cmd_to_run_before_test)
   set(cmd_to_run_before_test)
 endif()
@@ -50,16 +58,26 @@ foreach(s IN LISTS additional_paths)
   endif()
 endforeach()
 
-set(unittest_to_run "runtests('${unittest_file_to_run_name}'), 
exit(max([ans(1,:).Failed]))")
+if(custom_Matlab_test_command)
+  set(unittest_to_run ${custom_Matlab_test_command})
+else()
+  set(unittest_to_run "runtests('${unittest_file_to_run_name}'), 
exit(max([ans(1,:).Failed]))")
+endif()
+
+
 if(no_unittest_framework)
   set(unittest_to_run "try, ${unittest_file_to_run_name}, catch err, disp('An 
exception has been thrown during the execution'), disp(err), disp(err.stack), 
exit(1), end, exit(0)")
 endif()
 
 set(Matlab_SCRIPT_TO_RUN
-    "addpath(${concat_string}), path, ${cmd_to_run_before_test}, 
${unittest_to_run}"
-   )
+    "addpath(${concat_string}); ${cmd_to_run_before_test}; ${unittest_to_run}")
+
+if(NOT working_directory)
+  set(working_directory "${output_directory}")
+endif()
 
-set(Matlab_LOG_FILE "${output_directory}/${test_name}.log")
+string(REPLACE "/" "_" clean_test_name "${test_name}")
+set(Matlab_LOG_FILE "${output_directory}/${clean_test_name}.log")
 
 set(devnull)
 if(UNIX)
@@ -69,11 +87,11 @@ elseif(WIN32)
 endif()
 
 execute_process(
-  COMMAND "${Matlab_PROGRAM}" ${Matlab_UNIT_TESTS_CMD} -logfile 
"${test_name}.log" -r "${Matlab_SCRIPT_TO_RUN}"
+  COMMAND "${Matlab_PROGRAM}" ${Matlab_UNIT_TESTS_CMD} -logfile 
"${Matlab_LOG_FILE}" -r "${Matlab_SCRIPT_TO_RUN}"
   RESULT_VARIABLE res
-  TIMEOUT ${test_timeout}
+  ${test_timeout}
   OUTPUT_QUIET # we do not want the output twice
-  WORKING_DIRECTORY "${output_directory}"
+  WORKING_DIRECTORY ${working_directory}
   ${devnull}
   )
 
@@ -87,5 +105,5 @@ message("Matlab test ${name_of_the_test} 
output:\n${matlab_log_content}") # if w
 
 
 if(NOT (res EQUAL 0))
-  message( FATAL_ERROR "[MATLAB] TEST FAILED" )
+  message( FATAL_ERROR "[MATLAB] TEST FAILED Matlab returned ${res}" )
 endif()

-----------------------------------------------------------------------

Summary of changes:
 Modules/FindMatlab.cmake          |   50 ++++++++++++++++++++++++++++---------
 Modules/MatlabTestsRedirect.cmake |   36 +++++++++++++++++++-------
 2 files changed, 65 insertions(+), 21 deletions(-)


hooks/post-receive
diff --git a/Modules/FindMatlab.cmake b/Modules/FindMatlab.cmake
index 9f96fe6..aaca953 100644
--- a/Modules/FindMatlab.cmake
+++ b/Modules/FindMatlab.cmake
@@ -635,7 +635,7 @@ function(matlab_get_version_from_matlab_run 
matlab_binary_program matlab_list_ve
     set(devnull INPUT_FILE NUL)
   endif()
 
   # timeout set to 30 seconds, in case it does not start
   # note as said before OUTPUT_VARIABLE cannot be used in a platform
   # independent manner however, not setting it would flush the output of Matlab
   # in the current console (unix variant)
@@ -644,12 +644,17 @@ function(matlab_get_version_from_matlab_run 
matlab_binary_program matlab_list_ve
     OUTPUT_VARIABLE _matlab_version_from_cmd_dummy
     RESULT_VARIABLE _matlab_result_version_call
     ERROR_VARIABLE _matlab_result_version_call_error
-    TIMEOUT 30
+    TIMEOUT 120
     WORKING_DIRECTORY "${_matlab_temporary_folder}"
     ${devnull}
     )
-
-
+  if("${_matlab_result_version_call}" MATCHES "timeout")
+    if(MATLAB_FIND_DEBUG)
+      message(WARNING "[MATLAB] Unable to determine the version of Matlab."
+        " Matlab call timed out after 120 seconds.")
+    endif()
+    return()
+  endif()
   if(${_matlab_result_version_call})
     if(MATLAB_FIND_DEBUG)
       message(WARNING "[MATLAB] Unable to determine the version of Matlab. 
Matlab call returned with error ${_matlab_result_version_call}.")
@@ -698,7 +703,6 @@ function(matlab_get_version_from_matlab_run 
matlab_binary_program matlab_list_ve
 
 endfunction()
 
-
 #.rst:
 # .. command:: matlab_add_unit_test
 #
@@ -720,6 +724,7 @@ endfunction()
 #     matlab_add_unit_test(
 #         NAME <name>
 #         UNITTEST_FILE matlab_file_containing_unittest.m
+#         [CUSTOM_MATLAB_COMMAND matlab_command_to_run_as_test]
 #         [UNITTEST_PRECOMMAND matlab_command_to_run]
 #         [TIMEOUT timeout]
 #         [ADDITIONAL_PATH path1 [path2 ...]]
@@ -735,6 +740,11 @@ endfunction()
 #   ``UNITTEST_FILE``
 #     the matlab unittest file. Its path will be automatically
 #     added to the Matlab path.
+#   ``CUSTOM_MATLAB_COMMAND``
+#     Matlab script command to run as the test.
+#     IIf this is not set, then the following is run:
+#     "runtests('matlab_file_name'), exit(max([ans(1,:).Failed]))
+#     matlab_file_name comes from UNITTEST_FILE without the .m.
 #   ``UNITTEST_PRECOMMAND``
 #     Matlab script command to be ran before the file
 #     containing the test (eg. GPU device initialisation based on CMake
@@ -748,6 +758,7 @@ endfunction()
 #   ``MATLAB_ADDITIONAL_STARTUP_OPTIONS``
 #     a list of additional option in order
 #     to run Matlab from the command line.
+#     -nosplash -nodesktop -nodisplay are always added.
 #   ``TEST_ARGS``
 #     Additional options provided to the add_test command. These
 #     options are added to the default options (eg. "CONFIGURATIONS Release")
@@ -762,8 +773,9 @@ function(matlab_add_unit_test)
   endif()
 
   set(options NO_UNITTEST_FRAMEWORK)
-  set(oneValueArgs NAME UNITTEST_PRECOMMAND UNITTEST_FILE TIMEOUT)
-  set(multiValueArgs ADDITIONAL_PATH MATLAB_ADDITIONAL_STARTUP_OPTIONS 
TEST_ARGS)
+  set(oneValueArgs NAME UNITTEST_FILE TIMEOUT WORKING_DIRECTORY)
+  set(multiValueArgs UNITTEST_PRECOMMAND ADDITIONAL_PATH
+    MATLAB_ADDITIONAL_STARTUP_OPTIONS TEST_ARGS CUSTOM_TEST_COMMAND)
 
   set(prefix _matlab_unittest_prefix)
   cmake_parse_arguments(${prefix} "${options}" "${oneValueArgs}" 
"${multiValueArgs}" ${ARGN} )
@@ -772,17 +784,29 @@ function(matlab_add_unit_test)
     message(FATAL_ERROR "[MATLAB] The Matlab test name cannot be empty")
   endif()
 
+  # escape matlab commands so they can be passed to add_test
+  # and to cmake -P script.
+
+  string(REPLACE "\"" "" custom_test_cmd_clean 
"${${prefix}_CUSTOM_TEST_COMMAND}")
+  string(REPLACE ";" "\\;" custom_test_cmd_clean "${custom_test_cmd_clean}")
+  string(REPLACE "\"" "" unittest_precmd_clean 
"${${prefix}_UNITTEST_PRECOMMAND}")
+  string(REPLACE ";" "\\;" unittest_precmd_clean "${unittest_precmd_clean}")
+  string(REPLACE " " "\ " unittest_precmd_clean "${unittest_precmd_clean}")
+  string(REPLACE ";" "\\;" additional_path_clean 
"${${prefix}_ADDITIONAL_PATH}")
+
   add_test(NAME ${${prefix}_NAME}
            COMMAND ${CMAKE_COMMAND}
             -Dtest_name=${${prefix}_NAME}
-            -Dadditional_paths=${${prefix}_ADDITIONAL_PATH}
+            -Dadditional_paths=${additional_path_clean}
             -Dtest_timeout=${${prefix}_TIMEOUT}
             -Doutput_directory=${_matlab_temporary_folder}
+            -Dworking_directory=${${prefix}_WORKING_DIRECTORY}
             -DMatlab_PROGRAM=${Matlab_MAIN_PROGRAM}
             -Dno_unittest_framework=${${prefix}_NO_UNITTEST_FRAMEWORK}
             
-DMatlab_ADDITIONNAL_STARTUP_OPTIONS=${${prefix}_MATLAB_ADDITIONAL_STARTUP_OPTIONS}
             -Dunittest_file_to_run=${${prefix}_UNITTEST_FILE}
-            -Dcmd_to_run_before_test=${${prefix}_UNITTEST_PRECOMMAND}
+            -Dcustom_Matlab_test_command=${custom_test_cmd_clean}
+            -Dcmd_to_run_before_test=${unittest_precmd_clean}
             -P ${_FindMatlab_SELF_DIR}/MatlabTestsRedirect.cmake
            ${${prefix}_TEST_ARGS}
            ${${prefix}_UNPARSED_ARGUMENTS}
@@ -1029,9 +1053,11 @@ function(_Matlab_get_version_from_root matlab_root 
matlab_known_version matlab_f
 
   set(matlab_list_of_all_versions)
   
matlab_get_version_from_matlab_run("${Matlab_PROG_VERSION_STRING_AUTO_DETECT}" 
matlab_list_of_all_versions)
-
-  list(GET matlab_list_of_all_versions 0 _matlab_version_tmp)
-
+  if(matlab_list_of_all_versions)
+    list(GET matlab_list_of_all_versions 0 _matlab_version_tmp)
+  else()
+    set(_matlab_version_tmp "unknown")
+  endif()
   # set the version into the cache
   set(Matlab_VERSION_STRING_INTERNAL ${_matlab_version_tmp} CACHE INTERNAL 
@@ -635,7 +635,7 @@ function(matlab_get_version_from_matlab_run 
   endif()
 
-  # timeout set to 30 seconds, in case it does not start
+  # timeout set to 120 seconds, in case it does not start
   # note as said before OUTPUT_VARIABLE cannot be used in a platform
   # independent manner however, not setting it would flush the output of Matlab
"Matlab version (automatically determined)" FORCE)
 
-- 
CMake
_______________________________________________
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits

Reply via email to